This repo contains an example of a simple game written using Csound and the Phaser3 framework. Provided below is an overview of how the two work together in this context. The code below uses ES6-based techniques, but works just as well in traditional JS code. 

### Getting started: Loading Phaser3 and WebCsound

Phaser3 is a framwork for generating Javascript based games, while WebCsound is a web assembly version of the know well established audio programming language Csound. The two libraries need to be loaded before calling any game scripts. The loading of the library scripts happens in the game.html file, before any other scripts are called:

```html
<!doctype html> 
<html lang="en"> 
<head> 
    <meta charset="UTF-8" />
    <title>Game</title>
    <script src="//cdn.jsdelivr.net/npm/phaser@3.15.0/dist/phaser.js"></script>
    <script src="csound-wasm-browser.js"></script>
    <script src="csound.js"></script>
    <script src="mainLevel.js"></script>
    <script src="game.js"></script>
    <link rel="stylesheet" type="text/css" href="style.css"> -->
</head>
<body>
</body>
</html>
```

* Note that the games uses a forked version of WebCsound available through [this](...) repo. It works just the same as the offical WebCsound, but is provided as a single JS file rather a collection of different scripts.  

### Creating a scene. 

Scenes are created in Phaser3 by creating a new `Phaser.Scene` object. Below is code for a barebones scene.

```javascript
class GameScene extends Phaser.Scene {

    constructor (config)
    {
        super(config);
    }

    preload ()
    {
    }

    create ()
    {
    }

    update ()
    {
    }
};

//basic config for game
var config = {
    type: Phaser.AUTO,
        width: 800,
        height: 600,
        scene: {
            preload: preload,
            create: create,
            update: update
        }
};


var game = new Phaser.Game(config);

</script>
```

The first line of code declares a new class called `GameScene` which extends the `Phaser.Scene` class. The constructor is passed a JSON configuration var that declares the type of dimensions of the game, and the functions that will be used for preloading, creating, and updating throughout the game. The type filed sets which system is used for displaying the grpahics. It deaults to WebGL, but you can also set it to use the HTML5 Canvas.

### The preload function

The preload function will load all assets needed for the game, including audio. The `load.image()` method can be used to load any sprites needed by the scene.  

```html
(...)
preload ()
{
    this.load.spritesheet('spike', 'assets/spike.png', { frameWidth: 39, frameHeight: 48 });
}
(...)
```

The assets folder in this case is located in the same directory as the game itself. spike.png is a spritesheet that contains 9 frames of Spikes in various walking positions and directions. 'spike' is the name of the sprite, and is used later when we need to access the  

<iframe width="560" height="315" src="https://www.youtube.com/embed/dHHmUF9gs70" frameborder="0" allowfullscreen></iframe>